eml package
===========

Package for reading and writing `Ecological Metadata Language <https://eml.ecoinformatics.org/>`_.

EML Class
---------

.. automodule:: eml.base.eml
   :members:
   :undoc-members:
   :show-inheritance:

EMLVersion Class
----------------

.. automodule:: eml.base.version
   :members:
   :undoc-members:
   :show-inheritance:

EMLObject Base Class
--------------------

.. automodule:: eml.types.eml_object
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   eml.types
   eml.resources
